@@ -1,25 +1,26 @@
 context("Data")
-ds = Data$new(iris)
-sample1 = ds$sample(3)
-n = 100
+ds <- Data$new(iris)
+sample1 <- ds$sample(3)
+n <- 100
 set.seed(42)
-sample1.weighted = ds$sample(n, prob = c(2,1, rep(0, times = nrow(iris)- 2)))
+sample1.weighted <- ds$sample(n, prob = c(2, 1, rep(0, times = nrow(iris) - 2)))
 
-ds.weighted = Data$new(iris, prob = c(2,1, rep(0, times = nrow(iris)- 2)))
+ds.weighted <- Data$new(iris, prob = c(2, 1, rep(0, times = nrow(iris) - 2)))
 set.seed(42)
 
-sample2 = ds.weighted$sample(n)
+sample2 <- ds.weighted$sample(n)
 
-test_that("samplings works",{
+test_that("samplings works", {
   expect_class(sample1, "data.frame")
   expect_equal(colnames(sample1), colnames(iris))
   expect_equal(ds$get.x(), data.table(iris))
   expect_equal(ds$feature.names, colnames(iris))
-  expect_equal(ds$feature.types, c(Sepal.Length="numerical", 
-    Sepal.Width = "numerical", Petal.Length = "numerical", Petal.Width =  "numerical", 
-    Species = "categorical"))
+  expect_equal(ds$feature.types, c(
+    Sepal.Length = "numerical",
+    Sepal.Width = "numerical", Petal.Length = "numerical", Petal.Width = "numerical",
+    Species = "categorical"
+  ))
   expect_equal(ds$n.features, 5)
-
 })
 
 test_that("weighted sampling works", {
@@ -30,11 +31,11 @@ test_that("weighted sampling works", {
 
 
 test_that("y as character works", {
-  ds = Data$new(iris, y = "Species")
+  ds <- Data$new(iris, y = "Species")
   expect_equal(ds$y, iris["Species"])
   expect_equal(ds$X, data.table::data.table(iris[names(iris) != "Species"]))
   expect_equal(ds$get.xy(), data.table::data.table(iris))
   expect_equal(ds$get.x(), data.table::data.table(iris[names(iris) != "Species"]))
   expect_equal(ds$feature.names, setdiff(colnames(iris), "Species"))
   expect_equal(unname(ds$feature.types), rep("numerical", times = 4))
-})
\ No newline at end of file
+})
